@@ -1,4 +1,4 @@
-(* $Id: netplex_cenv.mli 1708 2012-02-16 00:12:17Z gerd $ *)
+(* $Id: netplex_cenv.mli 1774 2012-04-03 21:28:51Z gerd $ *)
 
 (** Container environment
   *
@@ -327,6 +327,18 @@ module Make_lever(T:FUN_TYPE) : LEVER with type s=T.s and type r=T.r
    *)
 
 
+(** {2 Persistent kernel objects} *)
+
+val pmanage : unit -> Netsys_pmanage.pmanage
+  (** Access the manager for persistent kernel objects with limited
+      lifetime. Among these objects there are shared memory objects,
+      and named semaphores. These objects can usually be deleted when
+      the program finishes (or crashes), but this is not done automatically
+      because of kernel persistency.
+
+      See {!Netplex_admin.unlink} for more information.
+   *)
+
 (** {1 Debugging} *)
 
 module Debug : sig
