@@ -1,7 +1,15 @@
-(* $Id: netsys_win32.mli 1505 2010-12-15 19:15:22Z gerd $ *)
+(* $Id: netsys_win32.mli 2195 2015-01-01 12:23:39Z gerd $ *)
 
 (** Primitives for Win32 *)
 
+(** {1 Files} *)
+
+val get_full_path_name : string -> string
+  (** Calls GetFullPathName *)
+
+val get_long_path_name : string -> string
+  (** Calls GetLongPathName *)
+
 (** {1 Event objects} *)
 
 type w32_event
